@@ -42,17 +42,14 @@
 #include <KAboutApplicationDialog>
 #include <KAuthorized>
 #include <KBugReport>
-#include <KActionCollection>
-#include <KDeclarative/KDeclarative>
 #include <KLocalizedString>
-#include <KMessageBox>
-#include <KHelpMenu>
+#include <KLocalizedContext>
 #include <KAboutData>
-#include <KHelpMenu>
-#include <KShortcutsDialog>
 #include <KConcatenateRowsProxyModel>
 #include <KSharedConfig>
 #include <KConfigGroup>
+#include <KStandardAction>
+#include <KIO/AccessManager>
 // #include <KSwitchLanguageDialog>
 
 // DiscoverCommon includes
@@ -79,6 +76,17 @@ public:
     }
 };
 
+class KIOAccessManagerFactory : public QQmlNetworkAccessManagerFactory
+{
+public:
+    KIOAccessManagerFactory() = default;
+    ~KIOAccessManagerFactory() = default;
+    QNetworkAccessManager *create(QObject *parent) override
+    {
+        return new KIO::AccessManager(parent);
+    }
+};
+
 DiscoverObject::DiscoverObject(CompactMode mode)
     : QObject()
     , m_engine(new QQmlApplicationEngine)
@@ -86,9 +94,11 @@ DiscoverObject::DiscoverObject(CompactMode mode)
     , m_networkAccessManagerFactory(new CachedNetworkAccessManagerFactory)
 {
     setObjectName(QStringLiteral("DiscoverMain"));
-    KDeclarative::KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(m_engine);
-    kdeclarative.setupBindings();
+    m_engine->rootContext()->setContextObject(new KLocalizedContext(m_engine));
+    auto factory = m_engine->networkAccessManagerFactory();
+    m_engine->setNetworkAccessManagerFactory(nullptr);
+    delete factory;
+    m_engine->setNetworkAccessManagerFactory(new KIOAccessManagerFactory());
 
     qmlRegisterType<UnityLauncher>("org.kde.discover.app", 1, 0, "UnityLauncher");
     qmlRegisterType<PaginateModel>("org.kde.discover.app", 1, 0, "PaginateModel");
@@ -166,7 +176,7 @@ void DiscoverObject::openMimeType(const QString& mime)
 
 void DiscoverObject::openCategory(const QString& category)
 {
-    rootObject()->setProperty("defaultStartup", false);
+    setRootObjectProperty("defaultStartup", false);
     auto action = new OneTimeAction(
         [this, category]() {
             Category* cat = CategoryModel::global()->findCategoryByName(category);
@@ -174,7 +184,7 @@ void DiscoverObject::openCategory(const QString& category)
                 emit listCategoryInternal(cat);
             } else {
                 showPassiveNotification(i18n("Could not find category '%1'", category));
-                rootObject()->setProperty("defaultStartup", false);
+                setRootObjectProperty("defaultStartup", false);
             }
         }
         , this);
@@ -193,7 +203,7 @@ void DiscoverObject::openLocalPackage(const QUrl& localfile)
         qWarning() << "Trying to open unexisting file" << localfile;
         return;
     }
-    rootObject()->setProperty("defaultStartup", false);
+    setRootObjectProperty("defaultStartup", false);
     auto action = new OneTimeAction(
         [this, localfile]() {
             auto res = ResourcesModel::global()->resourceForFile(localfile);
@@ -201,7 +211,7 @@ void DiscoverObject::openLocalPackage(const QUrl& localfile)
             if (res) {
                 emit openApplicationInternal(res);
             } else {
-                rootObject()->setProperty("defaultStartup", true);
+                setRootObjectProperty("defaultStartup", true);
                 showPassiveNotification(i18n("Couldn't open %1", localfile.toDisplayString()));
             }
         }
@@ -217,7 +227,7 @@ void DiscoverObject::openLocalPackage(const QUrl& localfile)
 void DiscoverObject::openApplication(const QUrl& url)
 {
     Q_ASSERT(!url.isEmpty());
-    rootObject()->setProperty("defaultStartup", false);
+    setRootObjectProperty("defaultStartup", false);
     auto action = new OneTimeAction(
         [this, url]() {
             AbstractResourcesBackend::Filters f;
@@ -228,7 +238,7 @@ void DiscoverObject::openApplication(const QUrl& url)
                 if (res.count() == 1) {
                     emit openApplicationInternal(res.first());
                 } else {
-                    rootObject()->setProperty("defaultStartup", true);
+                    setRootObjectProperty("defaultStartup", true);
                     showPassiveNotification(i18n("Couldn't open %1", url.toDisplayString()));
                 }
             });
@@ -403,6 +413,17 @@ QWindow* DiscoverObject::rootObject() const
     return qobject_cast<QWindow*>(m_engine->rootObjects().at(0));
 }
 
+void DiscoverObject::setRootObjectProperty(const char* name, const QVariant& value)
+{
+    auto ro = rootObject();
+    if (!ro) {
+        qWarning() << "please check your installation";
+        return;
+    }
+
+    rootObject()->setProperty(name, value);
+}
+
 void DiscoverObject::showPassiveNotification(const QString& msg)
 {
     QTimer::singleShot(100, this, [this, msg](){
