@@ -269,6 +269,11 @@ void PackageKitBackend::includePackagesToAdd()
         foreach(const auto &pkg, pkgs) {
             auto res = m_packages.packages.take(pkg);
             if (res) {
+                if (AppPackageKitResource* ares = qobject_cast<AppPackageKitResource*>(res)) {
+                    for(const auto &ext: res->extends())
+                        m_packages.extendedBy[ext].removeAll(ares);
+                }
+
                 emit resourceRemoved(res);
                 res->deleteLater();
             }
@@ -421,7 +426,17 @@ bool PackageKitBackend::hasSecurityUpdates() const
 
 int PackageKitBackend::updatesCount() const
 {
-    return upgradeablePackages().count();
+    int ret = 0;
+    QSet<QString> packages;
+    for(auto res: upgradeablePackages()) {
+        const auto packageName = res->packageName();
+        if (packages.contains(packageName)) {
+            continue;
+        }
+        packages.insert(packageName);
+        ret += 1;
+    }
+    return ret;
 }
 
 Transaction* PackageKitBackend::installApplication(AbstractResource* app, const AddonList& addons)
