@@ -26,6 +26,7 @@
 #include <PackageKit/Transaction>
 #include <functional>
 
+class QTimer;
 class QProcess;
 
 class PackageKitNotifier : public BackendNotifierModule
@@ -37,7 +38,6 @@ public:
     explicit PackageKitNotifier(QObject* parent = nullptr);
     ~PackageKitNotifier() override;
 
-    bool isSystemUpToDate() const override;
     uint securityUpdatesCount() override;
     uint updatesCount() override;
     void recheckSystemUpdateNeeded() override;
@@ -46,13 +46,24 @@ public:
 private Q_SLOTS:
     void package(PackageKit::Transaction::Info info, const QString &packageID, const QString &summary);
     void finished(PackageKit::Transaction::Exit exit, uint);
-    
+    void onRequireRestart(PackageKit::Transaction::Restart type, const QString &packageID);
+    void transactionListChanged(const QStringList &tids);
+    void onDistroUpgrade(PackageKit::Transaction::DistroUpgrade type, const QString &name, const QString &description);
+
 private:
+    void recheckSystemUpdate();
+    void checkOfflineUpdates();
+    void requireRestartNotification(PackageKit::Transaction::Restart type);
+    void setupGetUpdatesTransaction(PackageKit::Transaction* transaction);
     QProcess* checkAptVariable(const QString &aptconfig, const QLatin1String& varname, std::function<void(const QStringRef& val)> func);
 
     uint m_securityUpdates;
     uint m_normalUpdates;
     QPointer<PackageKit::Transaction> m_refresher;
+    QPointer<PackageKit::Transaction> m_distUpgrades;
+    QTimer* m_recheckTimer;
+
+    QHash<QString, PackageKit::Transaction*> m_transactions;
 };
 
 #endif
