@@ -26,10 +26,6 @@
 #include "AbstractResource.h"
 #include "utils.h"
 #include <QDateTime>
-#include <QDBusConnection>
-#include <QDBusInterface>
-#include <QDBusMessage>
-#include <QDBusReply>
 #include <QDebug>
 
 #include <KLocalizedString>
@@ -48,6 +44,7 @@ public:
             connect(updater, &AbstractBackendUpdater::progressingChanged, this, &UpdateTransaction::slotProgressingChanged);
             connect(updater, &AbstractBackendUpdater::progressChanged, this, &UpdateTransaction::slotUpdateProgress);
             connect(updater, &AbstractBackendUpdater::proceedRequest, this, &UpdateTransaction::processProceedRequest);
+            connect(updater, &AbstractBackendUpdater::cancelableChanged, this, [this](bool cancelable){ if (cancelable) setCancellable(true); });
             cancelable |= updater->isCancelable();
         }
         setCancellable(cancelable);
@@ -61,7 +58,7 @@ public:
     void cancel() override {
         QVector<AbstractBackendUpdater*> toCancel = m_updatersWaitingForFeedback.isEmpty() ? m_allUpdaters : m_updatersWaitingForFeedback;
 
-        foreach(auto updater, m_updatersWaitingForFeedback) {
+        foreach(auto updater, toCancel) {
             updater->cancel();
         }
     }
